import { useEffect, useRef } from 'react';
import scrollIntoView from 'scroll-into-view-if-needed';
import { useTypeaheadContext } from '../core/Context';
import { getMenuItemId, preventInputBlur } from '../utils';
function useItem({ label, option, position, ...props }) {
    const { activeIndex, id, isOnlyResult, onInitialItemChange, setItem } = useTypeaheadContext();
    const itemRef = useRef(null);
    useEffect(() => {
        if (position === 0) {
            onInitialItemChange(option);
        }
    });
    useEffect(() => {
        if (position === activeIndex) {
            const node = itemRef.current;
            node &&
                scrollIntoView(node, {
                    boundary: node.parentNode,
                    scrollMode: 'if-needed',
                });
        }
    }, [activeIndex, option, position]);
    const active = isOnlyResult || activeIndex === position;
    setItem(option, position, itemRef.current);
    return {
        ...props,
        active,
        'aria-label': label,
        'aria-selected': active,
        id: getMenuItemId(id, position),
        onMouseDown: preventInputBlur,
        ref: itemRef,
        role: 'option',
    };
}
export default useItem;
